# starfruit 

> like alien seeds that landed on earth,
> growing into strange plants.
> soon they may grow into trees, towering above us.
> some think they will bear fruit,
> a strange new abundance.
> for now, we admire their strange leaves.

try it:

```sh
$ pipx install starfruit
$ starfruit
```


